@@ -38,7 +38,6 @@
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
 
-#include <libempathy/empathy-call-factory.h>
 #include <libempathy/empathy-individual-manager.h>
 #include <libempathy/empathy-contact-groups.h>
 #include <libempathy/empathy-dispatcher.h>
@@ -163,11 +162,7 @@ individual_view_tooltip_destroy_cb (GtkWidget *widget,
 {
   EmpathyIndividualViewPriv *priv = GET_PRIV (view);
 
-  if (priv->tooltip_widget != NULL)
-    {
-      DEBUG ("Tooltip destroyed");
-      tp_clear_object (&priv->tooltip_widget);
-    }
+  tp_clear_object (&priv->tooltip_widget);
 }
 
 static gboolean
@@ -889,6 +884,17 @@ typedef struct
   guint32 time;
 } MenuPopupData;
 
+static void
+menu_deactivate_cb (GtkMenuShell *menushell,
+    gpointer user_data)
+{
+  /* FIXME: we shouldn't have to disconnec the signal (bgo #641327) */
+  g_signal_handlers_disconnect_by_func (menushell,
+      menu_deactivate_cb, user_data);
+
+  gtk_menu_detach (GTK_MENU (menushell));
+}
+
 static gboolean
 individual_view_popup_menu_idle_cb (gpointer user_data)
 {
@@ -906,8 +912,15 @@ individual_view_popup_menu_idle_cb (gpointer user_data)
       gtk_widget_show (menu);
       gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, data->button,
           data->time);
-      g_object_ref_sink (menu);
-      g_object_unref (menu);
+
+      /* menu is initially unowned but gtk_menu_attach_to_widget() taked its
+       * floating ref. We can either wait that the treeview releases its ref
+       * when it will be destroyed (when leaving Empathy) or explicitely
+       * detach the menu when it's not displayed any more.
+       * We go for the latter as we don't want to keep useless menus in memory
+       * during the whole lifetime of Empathy. */
+      g_signal_connect (menu, "deactivate", G_CALLBACK (menu_deactivate_cb),
+          NULL);
     }
 
   g_slice_free (MenuPopupData, data);
@@ -1038,7 +1051,7 @@ individual_view_call_activated_cb (EmpathyCellRendererActivatable *cell,
 
   event = (GdkEventButton *) gtk_get_current_event ();
 
-  menu = gtk_menu_new ();
+  menu = empathy_context_menu_new (GTK_WIDGET (view));
   shell = GTK_MENU_SHELL (menu);
 
   /* audio */
@@ -1051,12 +1064,9 @@ individual_view_call_activated_cb (EmpathyCellRendererActivatable *cell,
   gtk_menu_shell_append (shell, item);
   gtk_widget_show (item);
 
-  gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (view), NULL);
   gtk_widget_show (menu);
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
       event->button, event->time);
-  g_object_ref_sink (menu);
-  g_object_unref (menu);
 
   g_object_unref (individual);
 }
@@ -1671,6 +1681,7 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
   EmpathyLiveSearch *live = EMPATHY_LIVE_SEARCH (priv->search_widget);
   const gchar *str;
   GList *personas, *l;
+  gboolean is_favorite, contains_interesting_persona = FALSE;
 
   /* We're only giving the visibility wrt filtering here, not things like
    * presence. */
@@ -1680,8 +1691,24 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
       return FALSE;
     }
 
+  /* Hide all individuals which consist entirely of uninteresting personas */
+  personas = folks_individual_get_personas (individual);
+  for (l = personas; l; l = l->next)
+    {
+      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+        {
+          contains_interesting_persona = TRUE;
+          break;
+        }
+    }
+
+  if (contains_interesting_persona == FALSE)
+    return FALSE;
+
+  is_favorite = folks_favouritable_get_is_favourite (
+      FOLKS_FAVOURITABLE (individual));
   if (is_searching == FALSE)
-    return (priv->show_offline || is_online);
+    return (priv->show_offline || is_online || is_favorite);
 
   /* check alias name */
   str = folks_aliasable_get_alias (FOLKS_ALIASABLE (individual));
@@ -1690,14 +1717,13 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
     return TRUE;
 
   /* check contact id, remove the @server.com part */
-  personas = folks_individual_get_personas (individual);
   for (l = personas; l; l = l->next)
     {
       const gchar *p;
       gchar *dup_str = NULL;
       gboolean visible;
 
-      if (!TPF_IS_PERSONA (l->data))
+      if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
         continue;
 
       str = folks_persona_get_display_id (l->data);
@@ -1966,7 +1992,7 @@ individual_view_dispose (GObject *object)
 
   tp_clear_object (&priv->store);
   tp_clear_object (&priv->filter);
-  tp_clear_pointer (&priv->tooltip_widget, gtk_widget_destroy);
+  tp_clear_object (&priv->tooltip_widget);
 
   empathy_individual_view_set_live_search (view, NULL);
 
@@ -2375,7 +2401,7 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
        * be removed. */
       for (l = personas; l != NULL; l = l->next)
         {
-          if (!TPF_IS_PERSONA (l->data))
+          if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
             continue;
 
           persona_count++;
