@@ -199,6 +199,14 @@ contact_info_field_cmp (TpContactInfoField *field1,
   return contact_info_field_name_cmp (field1->field_name, field2->field_name);
 }
 
+static void
+client_types_notify_cb (TpContact *contact,
+    GParamSpec *pspec,
+    EmpathyIndividualWidget *self)
+{
+  client_types_update (self);
+}
+
 static void
 update_weak_contact (EmpathyIndividualWidget *self)
 {
@@ -230,8 +238,8 @@ update_weak_contact (EmpathyIndividualWidget *self)
 
           if (folks_presence_owner_typecmp (
                   folks_presence_owner_get_presence_type (presence),
-                  presence_type) > 0
-              && TPF_IS_PERSONA (presence))
+                  presence_type) > 0 &&
+              empathy_folks_persona_is_interesting (FOLKS_PERSONA (presence)))
             {
               presence_type = folks_presence_owner_get_presence_type (presence);
               tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
@@ -244,6 +252,9 @@ update_weak_contact (EmpathyIndividualWidget *self)
       priv->contact = tp_contact;
       g_object_add_weak_pointer (G_OBJECT (tp_contact),
           (gpointer *) &priv->contact);
+
+      g_signal_connect (priv->contact, "notify::client-types",
+          (GCallback) client_types_notify_cb, self);
     }
 }
 
@@ -422,7 +433,6 @@ static void
 details_update (EmpathyIndividualWidget *self)
 {
   EmpathyIndividualWidgetPriv *priv = GET_PRIV (self);
-  TpContact *tp_contact = NULL;
 
   if (!(priv->flags & EMPATHY_INDIVIDUAL_WIDGET_SHOW_DETAILS))
     return;
@@ -444,7 +454,7 @@ details_update (EmpathyIndividualWidget *self)
       data->contact = g_object_ref (priv->contact);
 
       /* First, make sure the CONTACT_INFO feature is ready on the connection */
-      connection = tp_contact_get_connection (tp_contact);
+      connection = tp_contact_get_connection (priv->contact);
       tp_proxy_prepare_async (connection, features,
           (GAsyncReadyCallback) details_feature_prepared_cb, data);
     }
@@ -571,7 +581,7 @@ location_update (EmpathyIndividualWidget *self)
     {
       FolksPersona *persona = FOLKS_PERSONA (l->data);
 
-      if (TPF_IS_PERSONA (persona))
+      if (empathy_folks_persona_is_interesting (persona))
         {
           TpContact *tp_contact;
 
@@ -718,8 +728,7 @@ location_update (EmpathyIndividualWidget *self)
 #ifdef HAVE_LIBCHAMPLAIN
   if (display_map == TRUE)
     {
-      GPtrArray *markers;
-      ChamplainLayer *layer;
+      ChamplainMarkerLayer *layer;
 
       priv->map_view_embed = gtk_champlain_embed_new ();
       priv->map_view = gtk_champlain_embed_get_view (
@@ -728,14 +737,12 @@ location_update (EmpathyIndividualWidget *self)
       gtk_container_add (GTK_CONTAINER (priv->viewport_map),
           priv->map_view_embed);
       g_object_set (G_OBJECT (priv->map_view),
-          "show-license", TRUE,
-          "scroll-mode", CHAMPLAIN_SCROLL_MODE_KINETIC,
+          "kinetic-mode", TRUE,
           "zoom-level", 10,
           NULL);
 
-      layer = champlain_layer_new ();
-      champlain_view_add_layer (priv->map_view, layer);
-      markers = g_ptr_array_new ();
+      layer = champlain_marker_layer_new ();
+      champlain_view_add_layer (priv->map_view, CHAMPLAIN_LAYER (layer));
 
       /* FIXME: For now, we have to do this manually. Once libfolks grows a
        * location interface, we can use that. (bgo#627400) */
@@ -744,7 +751,7 @@ location_update (EmpathyIndividualWidget *self)
         {
           FolksPersona *persona = FOLKS_PERSONA (l->data);
 
-          if (TPF_IS_PERSONA (persona))
+          if (empathy_folks_persona_is_interesting (persona))
             {
               gdouble lat = 0.0, lon = 0.0;
               ClutterActor *marker;
@@ -783,24 +790,20 @@ location_update (EmpathyIndividualWidget *self)
               lon = g_value_get_double (value);
 
               /* Add a marker to the map */
-              marker = champlain_marker_new_with_text (
+              marker = champlain_label_new_with_text (
                   folks_aliasable_get_alias (FOLKS_ALIASABLE (persona)), NULL,
                   NULL, NULL);
-              champlain_base_marker_set_position (
-                  CHAMPLAIN_BASE_MARKER (marker), lat, lon);
-              clutter_container_add (CLUTTER_CONTAINER (layer), marker, NULL);
-
-              g_ptr_array_add (markers, marker);
+              champlain_location_set_location (CHAMPLAIN_LOCATION (marker),
+                  lat, lon);
+              champlain_marker_layer_add_marker (layer,
+                  CHAMPLAIN_MARKER (marker));
 
               g_object_unref (contact);
             }
         }
 
       /* Zoom to show all of the markers */
-      g_ptr_array_add (markers, NULL); /* NULL-terminate the array */
-      champlain_view_ensure_markers_visible (priv->map_view,
-          (ChamplainBaseMarker **) markers->pdata, FALSE);
-      g_ptr_array_free (markers, TRUE);
+      champlain_view_ensure_layers_visible (priv->map_view, FALSE);
 
       gtk_widget_show_all (priv->viewport_map);
     }
@@ -809,14 +812,6 @@ location_update (EmpathyIndividualWidget *self)
     gtk_widget_show (priv->vbox_location);
 }
 
-static void
-client_types_notify_cb (TpContact *contact,
-    GParamSpec *pspec,
-    EmpathyIndividualWidget *self)
-{
-  client_types_update (self);
-}
-
 static void
 client_types_update (EmpathyIndividualWidget *self)
 {
@@ -850,8 +845,6 @@ client_types_update (EmpathyIndividualWidget *self)
       gtk_widget_hide (priv->hbox_client_types);
     }
 
-  g_signal_connect (priv->contact, "notify::client-types",
-      (GCallback) client_types_notify_cb, self);
 }
 
 static void
@@ -862,6 +855,9 @@ remove_weak_contact (EmpathyIndividualWidget *self)
   if (priv->contact == NULL)
     return;
 
+  g_signal_handlers_disconnect_by_func (priv->contact, client_types_notify_cb,
+      self);
+
   g_object_remove_weak_pointer (G_OBJECT (priv->contact),
       (gpointer *) &priv->contact);
   priv->contact = NULL;
@@ -874,7 +870,7 @@ persona_dup_avatar (FolksPersona *persona)
   EmpathyContact *contact;
   EmpathyAvatar *avatar;
 
-  if (!TPF_IS_PERSONA (persona))
+  if (!empathy_folks_persona_is_interesting (persona))
     return NULL;
 
   tp_contact = tpf_persona_get_contact (TPF_PERSONA (persona));
@@ -1015,7 +1011,7 @@ popup_avatar_menu (EmpathyIndividualWidget *self,
     return FALSE;
   empathy_avatar_unref (avatar);
 
-  menu = gtk_menu_new ();
+  menu = empathy_context_menu_new (parent);
 
   /* Add "Save as..." entry */
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_SAVE_AS, NULL);
@@ -1036,10 +1032,7 @@ popup_avatar_menu (EmpathyIndividualWidget *self,
       event_time = gtk_get_current_event_time ();
     }
 
-  gtk_menu_attach_to_widget (GTK_MENU (menu), parent, NULL);
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, event_time);
-  g_object_ref_sink (menu);
-  g_object_unref (menu);
 
   return TRUE;
 }
@@ -1472,7 +1465,7 @@ add_persona (EmpathyIndividualWidget *self,
   GtkWidget *label, *account_label, *account_image, *separator;
   guint current_row = 0;
 
-  if (!TPF_IS_PERSONA (persona))
+  if (!empathy_folks_persona_is_interesting (persona))
     return;
 
   if (priv->flags & EMPATHY_INDIVIDUAL_WIDGET_EDIT_FAVOURITE)
@@ -1575,7 +1568,7 @@ remove_persona (EmpathyIndividualWidget *self,
   GtkWidget *separator;
   GtkTable *table;
 
-  if (!TPF_IS_PERSONA (persona))
+  if (!empathy_folks_persona_is_interesting (persona))
     return;
 
   table = g_hash_table_lookup (priv->persona_tables, persona);
@@ -1647,7 +1640,7 @@ individual_table_set_up (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          if (TPF_IS_PERSONA (l->data))
+          if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
             num_personas++;
         }
 
@@ -1714,7 +1707,7 @@ personas_changed_cb (FolksIndividual *individual,
 
   for (l = personas; l != NULL; l = l->next)
     {
-      if (TPF_IS_PERSONA (l->data))
+      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
         new_num_personas++;
     }
 
@@ -1890,7 +1883,7 @@ individual_update (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          if (!TPF_IS_PERSONA (l->data))
+          if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
             continue;
 
           update_persona (self, FOLKS_PERSONA (l->data));
