@@ -510,8 +510,8 @@ empathy_contact_set_presence_message (EmpathyContact *contact,
 
   if (priv->persona != NULL)
     {
-      folks_has_presence_set_presence_message (
-          FOLKS_HAS_PRESENCE (priv->persona), message);
+      folks_presence_owner_set_presence_message (
+          FOLKS_PRESENCE_OWNER (priv->persona), message);
     }
 }
 
@@ -885,7 +885,7 @@ empathy_contact_get_persona (EmpathyContact *contact)
             {
               TpfPersona *persona = j->data;
 
-              if (TPF_IS_PERSONA (persona))
+              if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (persona)))
                 {
                   TpContact *tp_contact = tpf_persona_get_contact (persona);
 
@@ -991,10 +991,11 @@ empathy_contact_get_presence_message (EmpathyContact *contact)
   priv = GET_PRIV (contact);
 
   if (priv->persona != NULL)
-    {
-      return folks_has_presence_get_presence_message (
-          FOLKS_HAS_PRESENCE (priv->persona));
-    }
+    return folks_presence_owner_get_presence_message (
+        FOLKS_PRESENCE_OWNER (priv->persona));
+
+  if (priv->tp_contact != NULL)
+    return tp_contact_get_presence_message (priv->tp_contact);
 
   return NULL;
 }
@@ -1794,16 +1795,16 @@ static int
 presence_cmp_func (EmpathyContact *a,
     EmpathyContact *b)
 {
-  FolksHasPresence *presence_a, *presence_b;
+  FolksPresenceOwner *presence_a, *presence_b;
 
-  presence_a = FOLKS_HAS_PRESENCE (empathy_contact_get_persona (a));
-  presence_b = FOLKS_HAS_PRESENCE (empathy_contact_get_persona (b));
+  presence_a = FOLKS_PRESENCE_OWNER (empathy_contact_get_persona (a));
+  presence_b = FOLKS_PRESENCE_OWNER (empathy_contact_get_persona (b));
 
   /* We negate the result because we're sorting in reverse order (i.e. such that
    * the Personas with the highest presence are at the beginning of the list. */
-  return -folks_has_presence_typecmp (
-      folks_has_presence_get_presence_type (presence_a),
-      folks_has_presence_get_presence_type (presence_b));
+  return -folks_presence_owner_typecmp (
+      folks_presence_owner_get_presence_type (presence_a),
+      folks_presence_owner_get_presence_type (presence_b));
 }
 
 static gint
@@ -1957,7 +1958,7 @@ empathy_contact_dup_best_for_action (FolksIndividual *individual,
       TpContact *tp_contact;
       EmpathyContact *contact;
 
-      if (!TPF_IS_PERSONA (l->data))
+      if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
         continue;
 
       tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
