@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007-2008 Collabora Ltd.
+ * Copyright (C) 2007-2011 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -49,8 +49,7 @@
 #include "empathy-contact-manager.h"
 #include "empathy-individual-manager.h"
 #include "empathy-dispatcher.h"
-#include "empathy-idle.h"
-#include "empathy-tp-call.h"
+#include "empathy-presence-manager.h"
 #include "empathy-tp-contact-factory.h"
 
 #include <extensions/extensions.h>
@@ -238,6 +237,66 @@ empathy_xml_node_find_child_prop_value (xmlNodePtr   node,
 	return found;
 }
 
+GHashTable *
+empathy_call_create_streamed_media_request (EmpathyContact *contact,
+					    gboolean initial_audio,
+					    gboolean initial_video)
+{
+	return tp_asv_new (
+		TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
+			TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
+		TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
+			TP_HANDLE_TYPE_CONTACT,
+		TP_PROP_CHANNEL_TARGET_HANDLE, G_TYPE_UINT,
+			empathy_contact_get_handle (contact),
+		TP_PROP_CHANNEL_TYPE_STREAMED_MEDIA_INITIAL_AUDIO, G_TYPE_BOOLEAN,
+			initial_audio,
+		TP_PROP_CHANNEL_TYPE_STREAMED_MEDIA_INITIAL_VIDEO, G_TYPE_BOOLEAN,
+			initial_video,
+		NULL);
+}
+
+static void
+create_media_channel_cb (GObject *source,
+			 GAsyncResult *result,
+			 gpointer user_data)
+{
+	GError *error = NULL;
+
+	if (!tp_account_channel_request_create_channel_finish (TP_ACCOUNT_CHANNEL_REQUEST (source),
+							       result,
+							       &error)) {
+		DEBUG ("Failed to create StreamedMedia channel: %s", error->message);
+		g_error_free (error);
+	}
+}
+
+void
+empathy_call_new_with_streams (EmpathyContact *contact,
+			       gboolean initial_audio,
+			       gboolean initial_video,
+			       gint64 timestamp)
+{
+	GHashTable *request;
+	TpAccount *account;
+	TpAccountChannelRequest *req;
+
+	request = empathy_call_create_streamed_media_request (contact,
+							      initial_audio,
+							      initial_video);
+
+	account = empathy_contact_get_account (contact);
+
+	req = tp_account_channel_request_new (account, request, timestamp);
+
+	tp_account_channel_request_create_channel_async (req, NULL, NULL,
+							 create_media_channel_cb,
+							 NULL);
+
+	g_hash_table_unref (request);
+	g_object_unref (req);
+}
+
 const gchar *
 empathy_presence_get_default_message (TpConnectionPresenceType presence)
 {
@@ -482,11 +541,11 @@ gboolean
 empathy_check_available_state (void)
 {
 	TpConnectionPresenceType presence;
-	EmpathyIdle *idle;
+	EmpathyPresenceManager *presence_mgr;
 
-	idle = empathy_idle_dup_singleton ();
-	presence = empathy_idle_get_state (idle);
-	g_object_unref (idle);
+	presence_mgr = empathy_presence_manager_dup_singleton ();
+	presence = empathy_presence_manager_get_state (presence_mgr);
+	g_object_unref (presence_mgr);
 
 	if (presence != TP_CONNECTION_PRESENCE_TYPE_AVAILABLE &&
 		presence != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
@@ -723,7 +782,7 @@ empathy_folks_individual_contains_contact (FolksIndividual *individual)
   personas = folks_individual_get_personas (individual);
   for (l = personas; l != NULL; l = l->next)
     {
-      if (TPF_IS_PERSONA (l->data))
+      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
         return (tpf_persona_get_contact (TPF_PERSONA (l->data)) != NULL);
     }
 
@@ -750,7 +809,7 @@ empathy_contact_dup_from_folks_individual (FolksIndividual *individual)
     {
       TpfPersona *persona = l->data;
 
-      if (TPF_IS_PERSONA (persona))
+      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (persona)))
         {
           TpContact *tp_contact;
 
@@ -778,7 +837,7 @@ empathy_get_persona_store_for_connection (TpConnection *connection)
   TpfPersonaStore *result = NULL;
 
   backend_store = folks_backend_store_dup ();
-  backend = folks_backend_store_get_backend_by_name (backend_store,
+  backend = folks_backend_store_dup_backend_by_name (backend_store,
       "telepathy");
   if (backend != NULL)
     {
@@ -850,6 +909,24 @@ empathy_connection_can_group_personas (TpConnection *connection)
       FOLKS_MAYBE_BOOL_TRUE);
 }
 
+gboolean
+empathy_folks_persona_is_interesting (FolksPersona *persona)
+{
+  /* We're not interested in non-Telepathy personas */
+  if (!TPF_IS_PERSONA (persona))
+    return FALSE;
+
+  /* We're not interested in user personas which haven't been added to the
+   * contact list (see bgo#637151). */
+  if (folks_persona_get_is_user (persona) &&
+      !tpf_persona_get_is_in_contact_list (TPF_PERSONA (persona)))
+    {
+      return FALSE;
+    }
+
+  return TRUE;
+}
+
 gchar *
 empathy_get_x509_certificate_hostname (gnutls_x509_crt_t cert)
 {
