@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007-2008 Collabora Ltd.
+ * Copyright (C) 2007-2010 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -51,7 +51,7 @@
 #include <libempathy-gtk/empathy-log-window.h>
 #include <libempathy-gtk/empathy-geometry.h>
 #include <libempathy-gtk/empathy-smiley-manager.h>
-#include <libempathy-gtk/empathy-sound.h>
+#include <libempathy-gtk/empathy-sound-manager.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
 #include <libempathy-gtk/empathy-notify-manager.h>
 
@@ -59,6 +59,7 @@
 #include "empathy-chat-window.h"
 #include "empathy-about-dialog.h"
 #include "empathy-invite-participant-dialog.h"
+#include "gedit-close-button.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
 #include <libempathy/empathy-debug.h>
@@ -74,8 +75,6 @@
 typedef struct {
 	EmpathyChat *current_chat;
 	GList       *chats;
-	GList       *chats_new_msg;
-	GList       *chats_composing;
 	gboolean     page_added;
 	gboolean     dnd_same_window;
 	EmpathyChatroomManager *chatroom_manager;
@@ -115,6 +114,8 @@ typedef struct {
 	GSettings *gsettings_chat;
 	GSettings *gsettings_notif;
 	GSettings *gsettings_ui;
+
+	EmpathySoundManager *sound_mgr;
 } EmpathyChatWindowPriv;
 
 static GList *chat_windows = NULL;
@@ -219,20 +220,23 @@ chat_window_close_clicked_cb (GtkAction   *action,
 }
 
 static void
-chat_tab_style_set_cb (GtkWidget *hbox,
-				       GtkStyle  *previous_style,
-				       gpointer   user_data)
+chat_tab_style_updated_cb (GtkWidget *hbox,
+			   gpointer   user_data)
 {
 	GtkWidget *button;
 	int char_width, h, w;
 	PangoContext *context;
+	const PangoFontDescription *font_desc;
 	PangoFontMetrics *metrics;
 
 	button = g_object_get_data (G_OBJECT (user_data),
 		"chat-window-tab-close-button");
 	context = gtk_widget_get_pango_context (hbox);
 
-	metrics = pango_context_get_metrics (context, gtk_widget_get_style (hbox)->font_desc,
+	font_desc = gtk_style_context_get_font (gtk_widget_get_style_context (hbox),
+						GTK_STATE_FLAG_NORMAL);
+
+	metrics = pango_context_get_metrics (context, font_desc,
 		pango_context_get_language (context));
 	char_width = pango_font_metrics_get_approximate_char_width (metrics);
 	pango_font_metrics_unref (metrics);
@@ -257,8 +261,6 @@ chat_window_create_label (EmpathyChatWindow *window,
 	GtkWidget            *hbox;
 	GtkWidget            *name_label;
 	GtkWidget            *status_image;
-	GtkWidget            *close_button;
-	GtkWidget            *close_image;
 	GtkWidget            *event_box;
 	GtkWidget            *event_box_hbox;
 	PangoAttrList        *attr_list;
@@ -309,8 +311,9 @@ chat_window_create_label (EmpathyChatWindow *window,
 	gtk_box_pack_start (GTK_BOX (hbox), event_box, TRUE, TRUE, 0);
 
 	if (is_tab_label) {
-		close_button = gtk_button_new ();
-		gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
+		GtkWidget            *close_button;
+
+		close_button = gedit_close_button_new ();
 		g_object_set_data (G_OBJECT (chat), "chat-window-tab-close-button", close_button);
 
 		/* We don't want focus/keynav for the button to avoid clutter, and
@@ -319,13 +322,6 @@ chat_window_create_label (EmpathyChatWindow *window,
 		gtk_widget_set_can_focus (close_button, FALSE);
 		gtk_widget_set_can_default (close_button, FALSE);
 
-		/* Set the name to make the special rc style match. */
-		gtk_widget_set_name (close_button, "empathy-close-button");
-
-		close_image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-
-		gtk_container_add (GTK_CONTAINER (close_button), close_image);
-
 		gtk_box_pack_end (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 
 		g_signal_connect (close_button,
@@ -335,8 +331,8 @@ chat_window_create_label (EmpathyChatWindow *window,
 
 		/* React to theme changes and also setup the size correctly.  */
 		g_signal_connect (hbox,
-				  "style-set",
-				  G_CALLBACK (chat_tab_style_set_cb),
+				  "style-updated",
+				  G_CALLBACK (chat_tab_style_updated_cb),
 				  chat);
 	}
 
@@ -421,8 +417,14 @@ chat_window_contact_menu_update (EmpathyChatWindowPriv *priv,
 
 	if (orig_submenu == NULL || !gtk_widget_get_visible (orig_submenu)) {
 		submenu = empathy_chat_get_contact_menu (priv->current_chat);
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu), submenu);
-		gtk_widget_show (menu);
+		if (submenu != NULL) {
+			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu), submenu);
+			gtk_widget_show (menu);
+			gtk_widget_set_sensitive (menu, TRUE);
+		}
+		else {
+			gtk_widget_set_sensitive (menu, FALSE);
+		}
 	} else {
 		tp_g_signal_connect_object (orig_submenu,
 					     "notify::visible",
@@ -437,11 +439,8 @@ get_all_unread_messages (EmpathyChatWindowPriv *priv)
 	GList *l;
 	guint nb = 0;
 
-	for (l = priv->chats_new_msg; l != NULL; l = g_list_next (l)) {
-		EmpathyChat *chat = l->data;
-
-		nb += empathy_chat_get_nb_unread_messages (chat);
-	}
+	for (l = priv->chats; l != NULL; l = g_list_next (l))
+		nb += empathy_chat_get_nb_unread_messages (EMPATHY_CHAT (l->data));
 
 	return nb;
 }
@@ -523,7 +522,7 @@ chat_window_title_update (EmpathyChatWindowPriv *priv)
 }
 
 static void
-chat_window_icon_update (EmpathyChatWindowPriv *priv)
+chat_window_icon_update (EmpathyChatWindowPriv *priv, gboolean new_messages)
 {
 	GdkPixbuf      *icon;
 	EmpathyContact *remote_contact;
@@ -533,7 +532,7 @@ chat_window_icon_update (EmpathyChatWindowPriv *priv)
 	n_chats = g_list_length (priv->chats);
 
 	/* Update window icon */
-	if (priv->chats_new_msg) {
+	if (new_messages) {
 		gtk_window_set_icon_name (GTK_WINDOW (priv->dialog),
 					  EMPATHY_IMAGE_MESSAGE);
 	} else {
@@ -596,7 +595,7 @@ chat_window_update (EmpathyChatWindow *window)
 
 	chat_window_title_update (priv);
 
-	chat_window_icon_update (priv);
+	chat_window_icon_update (priv, get_all_unread_messages (priv) > 0);
 
 	chat_window_close_button_update (priv,
 					 num_pages);
@@ -657,10 +656,10 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 		/* No TpChat, we are disconnected */
 		icon_name = NULL;
 	}
-	else if (g_list_find (priv->chats_new_msg, chat)) {
+	else if (empathy_chat_get_nb_unread_messages (chat) > 0) {
 		icon_name = EMPATHY_IMAGE_MESSAGE;
 	}
-	else if (g_list_find (priv->chats_composing, chat)) {
+	else if (remote_contact && empathy_chat_is_composing (chat)) {
 		icon_name = EMPATHY_IMAGE_TYPING;
 	}
 	else if (remote_contact) {
@@ -705,7 +704,7 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 				      _("Topic:"), subject);
 	}
 
-	if (g_list_find (priv->chats_composing, chat)) {
+	if (remote_contact && empathy_chat_is_composing (chat)) {
 		append_markup_printf (tooltip, "\n%s", _("Typing a message."));
 	}
 
@@ -1234,16 +1233,6 @@ chat_window_composing_cb (EmpathyChat       *chat,
 			  gboolean          is_composing,
 			  EmpathyChatWindow *window)
 {
-	EmpathyChatWindowPriv *priv;
-
-	priv = GET_PRIV (window);
-
-	if (is_composing && !g_list_find (priv->chats_composing, chat)) {
-		priv->chats_composing = g_list_prepend (priv->chats_composing, chat);
-	} else {
-		priv->chats_composing = g_list_remove (priv->chats_composing, chat);
-	}
-
 	chat_window_update_chat_tab (chat);
 }
 
@@ -1346,7 +1335,7 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 }
 
 static void
-chat_window_set_highlight_room_tab_label (EmpathyChat *chat)
+chat_window_set_highlight_room_labels (EmpathyChat *chat)
 {
 	gchar *markup;
 	GtkWidget *widget;
@@ -1360,6 +1349,10 @@ chat_window_set_highlight_room_tab_label (EmpathyChat *chat)
 
 	widget = g_object_get_data (G_OBJECT (chat), "chat-window-tab-label");
 	gtk_label_set_markup (GTK_LABEL (widget), markup);
+
+	widget = g_object_get_data (G_OBJECT (chat), "chat-window-menu-label");
+	gtk_label_set_markup (GTK_LABEL (widget), markup);
+
 	g_free (markup);
 }
 
@@ -1381,6 +1374,7 @@ empathy_chat_window_has_focus (EmpathyChatWindow *window)
 static void
 chat_window_new_message_cb (EmpathyChat       *chat,
 			    EmpathyMessage    *message,
+			    gboolean pending,
 			    EmpathyChatWindow *window)
 {
 	EmpathyChatWindowPriv *priv;
@@ -1402,7 +1396,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 	sender = empathy_message_get_sender (message);
 
 	if (empathy_contact_is_user (sender)) {
-		empathy_sound_play (GTK_WIDGET (priv->dialog),
+		empathy_sound_manager_play (priv->sound_mgr, GTK_WIDGET (priv->dialog),
 				    EMPATHY_SOUND_MESSAGE_OUTGOING);
 	}
 
@@ -1414,8 +1408,8 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 		return;
 	}
 
-	if (!g_list_find (priv->chats_new_msg, chat)) {
-		priv->chats_new_msg = g_list_prepend (priv->chats_new_msg, chat);
+	/* Update the chat tab if this is the first unread message */
+	if (empathy_chat_get_nb_unread_messages (chat) == 1) {
 		chat_window_update_chat_tab (chat);
 	}
 
@@ -1448,19 +1442,25 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 	}
 
 	if (needs_urgency) {
+		chat_window_set_highlight_room_labels (chat);
+
 		if (!has_focus) {
 			chat_window_set_urgency_hint (window, TRUE);
-			chat_window_set_highlight_room_tab_label (chat);
 		}
 
-		empathy_sound_play (GTK_WIDGET (priv->dialog),
-		    EMPATHY_SOUND_MESSAGE_INCOMING);
-		chat_window_show_or_update_notification (window, message, chat);
+		/* Pending messages have already been displayed and notified in the
+		* approver, so we don't display a notification and play a sound for those */
+		if (!pending) {
+			empathy_sound_manager_play (priv->sound_mgr, GTK_WIDGET (priv->dialog),
+				    EMPATHY_SOUND_MESSAGE_INCOMING);
+
+			chat_window_show_or_update_notification (window, message, chat);
+		}
 	}
 
 	/* update the number of unread messages and the window icon */
 	chat_window_title_update (priv);
-	chat_window_icon_update (priv);
+	chat_window_icon_update (priv, TRUE);
 }
 
 static GtkNotebook *
@@ -1519,7 +1519,6 @@ chat_window_page_switched_cb (GtkNotebook      *notebook,
 	}
 
 	priv->current_chat = chat;
-	priv->chats_new_msg = g_list_remove (priv->chats_new_msg, chat);
 	empathy_chat_messages_read (chat);
 
 	chat_window_update_chat_tab (chat);
@@ -1611,9 +1610,7 @@ chat_window_page_removed_cb (GtkNotebook      *notebook,
 
 	/* Keep list of chats up to date */
 	priv->chats = g_list_remove (priv->chats, chat);
-	priv->chats_new_msg = g_list_remove (priv->chats_new_msg, chat);
 	empathy_chat_messages_read (chat);
-	priv->chats_composing = g_list_remove (priv->chats_composing, chat);
 
 	if (priv->chats == NULL) {
 		g_object_unref (window);
@@ -1631,7 +1628,6 @@ chat_window_focus_in_event_cb (GtkWidget        *widget,
 
 	priv = GET_PRIV (window);
 
-	priv->chats_new_msg = g_list_remove (priv->chats_new_msg, priv->current_chat);
 	empathy_chat_messages_read (priv->current_chat);
 
 	chat_window_set_urgency_hint (window, FALSE);
@@ -1873,6 +1869,7 @@ chat_window_finalize (GObject *object)
 	g_object_unref (priv->gsettings_chat);
 	g_object_unref (priv->gsettings_notif);
 	g_object_unref (priv->gsettings_ui);
+	g_object_unref (priv->sound_mgr);
 
 	if (priv->notification != NULL) {
 		notify_notification_close (priv->notification, NULL);
@@ -1907,16 +1904,6 @@ empathy_chat_window_class_init (EmpathyChatWindowClass *klass)
 	object_class->finalize = chat_window_finalize;
 
 	g_type_class_add_private (object_class, sizeof (EmpathyChatWindowPriv));
-
-	/* Set up a style for the close button with no focus padding. */
-	gtk_rc_parse_string (
-		"style \"empathy-close-button-style\"\n"
-		"{\n"
-		"  GtkWidget::focus-padding = 0\n"
-		"  xthickness = 0\n"
-		"  ythickness = 0\n"
-		"}\n"
-		"widget \"*.empathy-close-button\" style \"empathy-close-button-style\"");
 }
 
 static void
@@ -1988,6 +1975,8 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 	priv->gsettings_ui = g_settings_new (EMPATHY_PREFS_UI_SCHEMA);
 	priv->chatroom_manager = empathy_chatroom_manager_dup_singleton (NULL);
 
+	priv->sound_mgr = empathy_sound_manager_dup_singleton ();
+
 	priv->notebook = gtk_notebook_new ();
 
 	g_signal_connect (priv->notebook, "create-window",
@@ -2083,8 +2072,6 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 
 	/* Set up private details */
 	priv->chats = NULL;
-	priv->chats_new_msg = NULL;
-	priv->chats_composing = NULL;
 	priv->current_chat = NULL;
 	priv->notification = NULL;
 
