@@ -30,7 +30,9 @@
 
 #include <telepathy-glib/debug-sender.h>
 
-#include <libempathy/empathy-idle.h>
+#include <libempathy/empathy-presence-manager.h>
+
+#include <libempathy-gtk/empathy-theme-manager.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
 
 #include "empathy-chat-manager.h"
@@ -95,7 +97,8 @@ main (int argc,
   TpDebugSender *debug_sender;
 #endif
   GError *error = NULL;
-  EmpathyIdle *idle;
+  EmpathyPresenceManager *presence_mgr;
+  EmpathyThemeManager *theme_mgr;
   gint retval;
 
   /* Init */
@@ -118,6 +121,8 @@ main (int argc,
 
   empathy_gtk_init ();
 
+  /* Make empathy and empathy-chat appear as the same app in gnome-shell */
+  gdk_set_program_class ("Empathy");
   gtk_window_set_default_icon_name ("empathy");
   textdomain (GETTEXT_PACKAGE);
 
@@ -133,7 +138,10 @@ main (int argc,
 #endif
 
   /* Setting up Idle */
-  idle = empathy_idle_dup_singleton ();
+  presence_mgr = empathy_presence_manager_dup_singleton ();
+
+  /* Keep the theme manager alive as it does some caching */
+  theme_mgr = empathy_theme_manager_dup_singleton ();
 
   if (g_getenv ("EMPATHY_PERSIST") != NULL)
     {
@@ -152,7 +160,8 @@ main (int argc,
   retval = g_application_run (G_APPLICATION (app), argc, argv);
 
   g_object_unref (app);
-  g_object_unref (idle);
+  g_object_unref (presence_mgr);
+  g_object_unref (theme_mgr);
   tp_clear_object (&chat_mgr);
 
 #ifdef ENABLE_DEBUG
