@@ -29,14 +29,13 @@
 #include <telepathy-glib/interfaces.h>
 #include <telepathy-glib/simple-approver.h>
 
-#include <libempathy/empathy-idle.h>
+#include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-contact-manager.h>
 #include <libempathy/empathy-tp-chat.h>
-#include <libempathy/empathy-tp-call.h>
+#include <libempathy/empathy-tp-streamed-media.h>
 #include <libempathy/empathy-tp-file.h>
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-call-factory.h>
 #include <libempathy/empathy-gsettings.h>
 
 #include <extensions/extensions.h>
@@ -404,9 +403,9 @@ reject_channel_claim_cb (GObject *source,
       goto out;
     }
 
-  if (EMPATHY_IS_TP_CALL (user_data))
+  if (EMPATHY_IS_TP_STREAMED_MEDIA (user_data))
     {
-      empathy_tp_call_close (user_data);
+      empathy_tp_streamed_media_close (user_data);
     }
   else if (EMPATHY_IS_TP_CHAT (user_data))
     {
@@ -489,7 +488,7 @@ event_channel_process_voip_func (EventPriv *event)
   GtkWidget *dialog;
   GtkWidget *button;
   GtkWidget *image;
-  EmpathyTpCall *call;
+  EmpathyTpStreamedMedia *call;
   gboolean video;
   gchar *title;
 
@@ -499,9 +498,9 @@ event_channel_process_voip_func (EventPriv *event)
       return;
     }
 
-  call = EMPATHY_TP_CALL (event->approval->handler_instance);
+  call = EMPATHY_TP_STREAMED_MEDIA (event->approval->handler_instance);
 
-  video = empathy_tp_call_has_initial_video (call);
+  video = empathy_tp_streamed_media_has_initial_video (call);
 
   dialog = gtk_message_dialog_new (NULL, 0,
       GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
@@ -650,12 +649,12 @@ event_manager_media_channel_got_contact (EventManagerApproval *approval)
   EmpathyEventManagerPriv *priv = GET_PRIV (approval->manager);
   GtkWidget *window = empathy_main_window_dup ();
   gchar *header;
-  EmpathyTpCall *call;
+  EmpathyTpStreamedMedia *call;
   gboolean video;
 
-  call = EMPATHY_TP_CALL (approval->handler_instance);
+  call = EMPATHY_TP_STREAMED_MEDIA (approval->handler_instance);
 
-  video = empathy_tp_call_has_initial_video (call);
+  video = empathy_tp_streamed_media_has_initial_video (call);
 
   header = g_strdup_printf (
     video ? _("Incoming video call from %s") :_("Incoming call from %s"),
@@ -678,7 +677,7 @@ event_manager_media_channel_got_contact (EventManagerApproval *approval)
 }
 
 static void
-event_manager_media_channel_contact_changed_cb (EmpathyTpCall *call,
+event_manager_media_channel_contact_changed_cb (EmpathyTpStreamedMedia *call,
   GParamSpec *param, EventManagerApproval *approval)
 {
   EmpathyContact *contact;
@@ -975,7 +974,7 @@ approve_channels (TpSimpleApprover *approver,
   else if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_STREAMED_MEDIA)
     {
       EmpathyContact *contact;
-      EmpathyTpCall *call = empathy_tp_call_new (account, channel);
+      EmpathyTpStreamedMedia *call = empathy_tp_streamed_media_new (account, channel);
 
       approval->handler_instance = G_OBJECT (call);
 
@@ -1067,7 +1066,7 @@ event_manager_pendings_changed_cb (EmpathyContactList  *list,
     }
 
   header = g_strdup_printf (
-      _("%s would like permission to see when you are available"),
+      _("%s would like permission to see when you are online"),
       empathy_contact_get_alias (contact));
 
   if (!EMP_STR_EMPTY (message))
@@ -1092,13 +1091,13 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
   EmpathyEventManagerPriv *priv = GET_PRIV (manager);
   TpAccount *account;
   gchar *header = NULL;
-  EmpathyIdle *idle;
+  EmpathyPresenceManager *presence_mgr;
   GtkWidget *window = empathy_main_window_dup ();
 
   account = empathy_contact_get_account (contact);
-  idle = empathy_idle_dup_singleton ();
+  presence_mgr = empathy_presence_manager_dup_singleton ();
 
-  if (empathy_idle_account_is_just_connected (idle, account))
+  if (empathy_presence_manager_account_is_just_connected (presence_mgr, account))
     goto out;
 
   if (tp_connection_presence_type_cmp_availability (previous,
@@ -1149,7 +1148,7 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
   g_free (header);
 
 out:
-  g_object_unref (idle);
+  g_object_unref (presence_mgr);
   g_object_unref (window);
 }
 
